// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

var DotNetSupportLib = {
	$DOTNET: {
		conv_string: function (mono_obj) {
			return MONO.string_decoder.copy (mono_obj);
		}
	},
	mono_wasm_invoke_js_blazor: function(exceptionMessage, callInfo, arg0, arg1, arg2)	{
		var mono_string = globalThis._mono_string_cached
			|| (globalThis._mono_string_cached = Module.cwrap('mono_wasm_string_from_js', 'number', ['string']));

		try {
			var blazorExports = globalThis.Blazor;
			if (!blazorExports) {
				throw new Error('The blazor.webassembly.js library is not loaded.');
			}

			return blazorExports._internal.invokeJSFromDotNet(callInfo, arg0, arg1, arg2);
		} catch (ex) {
			var exceptionJsString = ex.message + '\n' + ex.stack;
			var exceptionSystemString = mono_string(exceptionJsString);
			setValue (exceptionMessage, exceptionSystemString, 'i32'); // *exceptionMessage = exceptionSystemString;
			return 0;
		}
	},

	// This is for back-compat only and will eventually be removed
	mono_wasm_invoke_js_marshalled: function(exceptionMessage, asyncHandleLongPtr, functionName, argsJson, treatResultAsVoid) {

		var mono_string = globalThis._mono_string_cached
			|| (globalThis._mono_string_cached = Module.cwrap('mono_wasm_string_from_js', 'number', ['string']));

		try {
			// Passing a .NET long into JS via Emscripten is tricky. The method here is to pass
			// as pointer to the long, then combine two reads from the HEAPU32 array.
			// Even though JS numbers can't represent the full range of a .NET long, it's OK
			// because we'll never exceed Number.MAX_SAFE_INTEGER (2^53 - 1) in this case.
			//var u32Index = $1 >> 2;
			var u32Index = asyncHandleLongPtr >> 2;
			var asyncHandleJsNumber = Module.HEAPU32[u32Index + 1]*4294967296 + Module.HEAPU32[u32Index];

			// var funcNameJsString = UTF8ToString (functionName);
			// var argsJsonJsString = argsJson && UTF8ToString (argsJson);
			var funcNameJsString = DOTNET.conv_string(functionName);
			var argsJsonJsString = argsJson && DOTNET.conv_string (argsJson);

			var dotNetExports = globaThis.DotNet;
			if (!dotNetExports) {
				throw new Error('The Microsoft.JSInterop.js library is not loaded.');
			}

			if (asyncHandleJsNumber) {
				dotNetExports.jsCallDispatcher.beginInvokeJSFromDotNet(asyncHandleJsNumber, funcNameJsString, argsJsonJsString, treatResultAsVoid);
				return 0;
			} else {
				var resultJson = dotNetExports.jsCallDispatcher.invokeJSFromDotNet(funcNameJsString, argsJsonJsString, treatResultAsVoid);
				return resultJson === null ? 0 : mono_string(resultJson);
			}
		} catch (ex) {
			var exceptionJsString = ex.message + '\n' + ex.stack;
			var exceptionSystemString = mono_string(exceptionJsString);
			setValue (exceptionMessage, exceptionSystemString, 'i32'); // *exceptionMessage = exceptionSystemString;
			return 0;
		}
	},

	// This is for back-compat only and will eventually be removed
	mono_wasm_invoke_js_unmarshalled: function(exceptionMessage, funcName, arg0, arg1, arg2)	{
		try {
			// Get the function you're trying to invoke
			var funcNameJsString = DOTNET.conv_string(funcName);
			var dotNetExports = globalThis.DotNet;
			if (!dotNetExports) {
				throw new Error('The Microsoft.JSInterop.js library is not loaded.');
			}
			var funcInstance = dotNetExports.jsCallDispatcher.findJSFunction(funcNameJsString);

			return funcInstance.call(null, arg0, arg1, arg2);
		} catch (ex) {
			var exceptionJsString = ex.message + '\n' + ex.stack;
			var mono_string = Module.cwrap('mono_wasm_string_from_js', 'number', ['string']); // TODO: Cache
			var exceptionSystemString = mono_string(exceptionJsString);
			setValue (exceptionMessage, exceptionSystemString, 'i32'); // *exceptionMessage = exceptionSystemString;
			return 0;
		}
	}


};

autoAddDeps(DotNetSupportLib, '$DOTNET')
mergeInto(LibraryManager.library, DotNetSupportLib)


// SIG // Begin signature block
// SIG // MIIorgYJKoZIhvcNAQcCoIIonzCCKJsCAQExDzANBglg
// SIG // hkgBZQMEAgEFADB3BgorBgEEAYI3AgEEoGkwZzAyBgor
// SIG // BgEEAYI3AgEeMCQCAQEEEBDgyQbOONQRoqMAEEvTUJAC
// SIG // AQACAQACAQACAQACAQAwMTANBglghkgBZQMEAgEFAAQg
// SIG // DQxM5aUosMIFmI353dLRcro0jWTAvinWkY5FLkoNZqCg
// SIG // gg3lMIIGYzCCBEugAwIBAgITMwAAA3zJ9rztB1muCAAA
// SIG // AAADfDANBgkqhkiG9w0BAQwFADB+MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBT
// SIG // aWduaW5nIFBDQSAyMDExMB4XDTIzMDUxMTE5MDMzMloX
// SIG // DTI0MDUwODE5MDMzMlowYzELMAkGA1UEBhMCVVMxEzAR
// SIG // BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
// SIG // bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
// SIG // bjENMAsGA1UEAxMELk5FVDCCAaIwDQYJKoZIhvcNAQEB
// SIG // BQADggGPADCCAYoCggGBAM7wia8MfPwd4mtILpj8qoFF
// SIG // 2NU9AGUh6KMxjoH5wsKo/CNMznlw6z6QDoXMd1SjRH/n
// SIG // mWLJ9UwKsIHC4wjcIIQA2oTK9wiBP2C4JADckr1ib5QF
// SIG // VIdjt1rgvt7QVuVcu3i+7vIlThcWBQFDCipaAmlQG5WS
// SIG // Lf3DbJZuL5FNO5hxjw5mqtZg/RifUhMu6gw/ZandJNcC
// SIG // 3TW3ZkLpWhjKdJIJh6omc+RYTQByB3XUt4P1wTh4Ah2w
// SIG // ImmwDnQMiHYgLiKTaP1TQBTbmB1o4ims4knVLsfrXKhR
// SIG // UumxtoBIN/YyvhwpJuXqJWTgUq13YyqxNEyNC1QWtGpc
// SIG // Ww+jSkX2sX6yNkxKexr1D+2lyu5C4nNHEox0huDXcn4C
// SIG // eEpERgkVAnxhPLB68NLqqzBa7kLv5V8cNl9rG2FE64AG
// SIG // QA9WxNNUiIt+ItJUgq1IF2t7tdJGvmsJDj07yV0TToU6
// SIG // 5kqUexgpLaDoZizsV4ZhPYjWHpv0D6juvnBPTt4ionDc
// SIG // nFsv9wIDAQABo4IBczCCAW8wHwYDVR0lBBgwFgYKKwYB
// SIG // BAGCN0wIAQYIKwYBBQUHAwMwHQYDVR0OBBYEFFKpamFH
// SIG // SEZcQyIedxp5ANsBMD5JMEUGA1UdEQQ+MDykOjA4MR4w
// SIG // HAYDVQQLExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xFjAU
// SIG // BgNVBAUTDTQ2NDIyMys1MDEwMTUwHwYDVR0jBBgwFoAU
// SIG // SG5k5VAF04KqFzc3IrVtqMp1ApUwVAYDVR0fBE0wSzBJ
// SIG // oEegRYZDaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3Br
// SIG // aW9wcy9jcmwvTWljQ29kU2lnUENBMjAxMV8yMDExLTA3
// SIG // LTA4LmNybDBhBggrBgEFBQcBAQRVMFMwUQYIKwYBBQUH
// SIG // MAKGRWh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lv
// SIG // cHMvY2VydHMvTWljQ29kU2lnUENBMjAxMV8yMDExLTA3
// SIG // LTA4LmNydDAMBgNVHRMBAf8EAjAAMA0GCSqGSIb3DQEB
// SIG // DAUAA4ICAQAOSEYc1GtkOHuaEONN2ZhGwBfVVOls91pV
// SIG // 9txVvKdJwl8XjM3UD80N0c4mvoVT6K1a8VgJom58eg7c
// SIG // 6HuwPsdvhNlaslOhXnFTHGUqJ++gXPDgH5a2w5j0IHTm
// SIG // yYkSv4NDSi9u2FtgWRjlfyag9r8kvBRUv/M8ISO2dqne
// SIG // LiQhJcTL95mFcpt7Jf2m+b25wM6S5BPvV4sgepZMQwGJ
// SIG // HBANg+w2YUfgQ430mnZHg70iI6V+rMEcPW6jFaf9B/5+
// SIG // vvXlw4yabr32W3ofks4OxTX8HVfRLO8uK/jdCODX2vAa
// SIG // Zeh7YNdtTGqMsOhI6KOW+IAQrUnvEbiRPmPqvgFjAH0e
// SIG // NUr/zy/Xt8gxBranFQdM1gVv57aU/HMtK8L8tpAT0Zjc
// SIG // h/4xE2oHpVdcIPxjISlHQJIL7NtEI0/WPNA7afEiUj8C
// SIG // Ztxg9ivyy/hLd+i4COfhFeraWsxkwM+oKKYpWJJFQTgJ
// SIG // Z8kHhoOTVxoxMseEfUalzoL0C+MHsDdsMn5VQw3LCuoq
// SIG // pnhG6vnN0TMNsbNydBflcBlACOPz+S6QNfp62r0JYWXw
// SIG // BbtRM+3A9dHtD4nqr/ZjtCAG8GdxU220D240BmU5/TZR
// SIG // OHHwPLl4Afmki/uogGvnFyd19wFHHG80gB5N9rsdKUsx
// SIG // hO+CqUzuQeurTLKzf6lKyjOfwYQ2IMpN1zCCB3owggVi
// SIG // oAMCAQICCmEOkNIAAAAAAAMwDQYJKoZIhvcNAQELBQAw
// SIG // gYgxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5n
// SIG // dG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVN
// SIG // aWNyb3NvZnQgQ29ycG9yYXRpb24xMjAwBgNVBAMTKU1p
// SIG // Y3Jvc29mdCBSb290IENlcnRpZmljYXRlIEF1dGhvcml0
// SIG // eSAyMDExMB4XDTExMDcwODIwNTkwOVoXDTI2MDcwODIx
// SIG // MDkwOVowfjELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldh
// SIG // c2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
// SIG // BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEoMCYGA1UE
// SIG // AxMfTWljcm9zb2Z0IENvZGUgU2lnbmluZyBQQ0EgMjAx
// SIG // MTCCAiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIB
// SIG // AKvw+nIQHC6t2G6qghBNNLrytlghn0IbKmvpWlCquAY4
// SIG // GgRJun/DDB7dN2vGEtgL8DjCmQawyDnVARQxQtOJDXlk
// SIG // h36UYCRsr55JnOloXtLfm1OyCizDr9mpK656Ca/XllnK
// SIG // YBoF6WZ26DJSJhIv56sIUM+zRLdd2MQuA3WraPPLbfM6
// SIG // XKEW9Ea64DhkrG5kNXimoGMPLdNAk/jj3gcN1Vx5pUkp
// SIG // 5w2+oBN3vpQ97/vjK1oQH01WKKJ6cuASOrdJXtjt7UOR
// SIG // g9l7snuGG9k+sYxd6IlPhBryoS9Z5JA7La4zWMW3Pv4y
// SIG // 07MDPbGyr5I4ftKdgCz1TlaRITUlwzluZH9TupwPrRkj
// SIG // hMv0ugOGjfdf8NBSv4yUh7zAIXQlXxgotswnKDglmDlK
// SIG // Ns98sZKuHCOnqWbsYR9q4ShJnV+I4iVd0yFLPlLEtVc/
// SIG // JAPw0XpbL9Uj43BdD1FGd7P4AOG8rAKCX9vAFbO9G9RV
// SIG // S+c5oQ/pI0m8GLhEfEXkwcNyeuBy5yTfv0aZxe/CHFfb
// SIG // g43sTUkwp6uO3+xbn6/83bBm4sGXgXvt1u1L50kppxMo
// SIG // pqd9Z4DmimJ4X7IvhNdXnFy/dygo8e1twyiPLI9AN0/B
// SIG // 4YVEicQJTMXUpUMvdJX3bvh4IFgsE11glZo+TzOE2rCI
// SIG // F96eTvSWsLxGoGyY0uDWiIwLAgMBAAGjggHtMIIB6TAQ
// SIG // BgkrBgEEAYI3FQEEAwIBADAdBgNVHQ4EFgQUSG5k5VAF
// SIG // 04KqFzc3IrVtqMp1ApUwGQYJKwYBBAGCNxQCBAweCgBT
// SIG // AHUAYgBDAEEwCwYDVR0PBAQDAgGGMA8GA1UdEwEB/wQF
// SIG // MAMBAf8wHwYDVR0jBBgwFoAUci06AjGQQ7kUBU7h6qfH
// SIG // MdEjiTQwWgYDVR0fBFMwUTBPoE2gS4ZJaHR0cDovL2Ny
// SIG // bC5taWNyb3NvZnQuY29tL3BraS9jcmwvcHJvZHVjdHMv
// SIG // TWljUm9vQ2VyQXV0MjAxMV8yMDExXzAzXzIyLmNybDBe
// SIG // BggrBgEFBQcBAQRSMFAwTgYIKwYBBQUHMAKGQmh0dHA6
// SIG // Ly93d3cubWljcm9zb2Z0LmNvbS9wa2kvY2VydHMvTWlj
// SIG // Um9vQ2VyQXV0MjAxMV8yMDExXzAzXzIyLmNydDCBnwYD
// SIG // VR0gBIGXMIGUMIGRBgkrBgEEAYI3LgMwgYMwPwYIKwYB
// SIG // BQUHAgEWM2h0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9w
// SIG // a2lvcHMvZG9jcy9wcmltYXJ5Y3BzLmh0bTBABggrBgEF
// SIG // BQcCAjA0HjIgHQBMAGUAZwBhAGwAXwBwAG8AbABpAGMA
// SIG // eQBfAHMAdABhAHQAZQBtAGUAbgB0AC4gHTANBgkqhkiG
// SIG // 9w0BAQsFAAOCAgEAZ/KGpZjgVHkaLtPYdGcimwuWEeFj
// SIG // kplCln3SeQyQwWVfLiw++MNy0W2D/r4/6ArKO79HqaPz
// SIG // adtjvyI1pZddZYSQfYtGUFXYDJJ80hpLHPM8QotS0LD9
// SIG // a+M+By4pm+Y9G6XUtR13lDni6WTJRD14eiPzE32mkHSD
// SIG // jfTLJgJGKsKKELukqQUMm+1o+mgulaAqPyprWEljHwlp
// SIG // blqYluSD9MCP80Yr3vw70L01724lruWvJ+3Q3fMOr5ko
// SIG // l5hNDj0L8giJ1h/DMhji8MUtzluetEk5CsYKwsatruWy
// SIG // 2dsViFFFWDgycScaf7H0J/jeLDogaZiyWYlobm+nt3TD
// SIG // QAUGpgEqKD6CPxNNZgvAs0314Y9/HG8VfUWnduVAKmWj
// SIG // w11SYobDHWM2l4bf2vP48hahmifhzaWX0O5dY0HjWwec
// SIG // hz4GdwbRBrF1HxS+YWG18NzGGwS+30HHDiju3mUv7Jf2
// SIG // oVyW2ADWoUa9WfOXpQlLSBCZgB/QACnFsZulP0V3HjXG
// SIG // 0qKin3p6IvpIlR+r+0cjgPWe+L9rt0uX4ut1eBrs6jeZ
// SIG // eRhL/9azI2h15q/6/IvrC4DqaTuv/DDtBEyO3991bWOR
// SIG // PdGdVk5Pv4BXIqF4ETIheu9BCrE/+6jMpF3BoYibV3FW
// SIG // TkhFwELJm3ZbCoBIa/15n8G9bW1qyVJzEw16UM0xghoh
// SIG // MIIaHQIBATCBlTB+MQswCQYDVQQGEwJVUzETMBEGA1UE
// SIG // CBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEe
// SIG // MBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSgw
// SIG // JgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBD
// SIG // QSAyMDExAhMzAAADfMn2vO0HWa4IAAAAAAN8MA0GCWCG
// SIG // SAFlAwQCAQUAoIGuMBkGCSqGSIb3DQEJAzEMBgorBgEE
// SIG // AYI3AgEEMBwGCisGAQQBgjcCAQsxDjAMBgorBgEEAYI3
// SIG // AgEVMC8GCSqGSIb3DQEJBDEiBCD3omjKU+2ltBtHmjuF
// SIG // e7vjmLFCFgQ9lehLg9Wo3349uDBCBgorBgEEAYI3AgEM
// SIG // MTQwMqAUgBIATQBpAGMAcgBvAHMAbwBmAHShGoAYaHR0
// SIG // cDovL3d3dy5taWNyb3NvZnQuY29tMA0GCSqGSIb3DQEB
// SIG // AQUABIIBgCy8eeytvvZGf0FhrSKOhlyDlEnMOf6RpgpD
// SIG // q0oGCjfd9mkc/w6PYQryagHZ1BQYDciXY4/6SrlC5eXq
// SIG // WiNXk/Qm3jWUgwoE++rHsAzo8DkHOKLIZWovR9B1m7z/
// SIG // E0dkPxTnt4U0b6UmgxnQ5oiX+o72F27FbxlU44dgXrha
// SIG // GSkNya/wNm9BR5dZBL+8XgWTAVDnCV1B8qwlYyp60TfK
// SIG // 2uy8t6Am12ov67QUqwkkEgfaVVovToTky7gROmcCn/66
// SIG // Ajge9RWARfy4dZcI0sCTVtHL65182CjDzaWD5ac3UfkM
// SIG // OOARhF+KIdh7xPiwSvOqLeaMMu+ScCniEE4Z1mXPsu6a
// SIG // 563rKN6Dhl1KIOG2e5YtgxiKKiK+2Qr5oAPlH5M8sNLr
// SIG // kVwx2wQ2qVLywP7O7rAXQ+1AkXtBNtjpn0xQBuG4K+gl
// SIG // WCbL+zly8G3XU609upL5TmtnrlFJ3eBMAD/BuJt8CwvD
// SIG // 0t3b/PSJ2Qul/0N7s6CvtuuWstl8wYuuoLTVfqGCFysw
// SIG // ghcnBgorBgEEAYI3AwMBMYIXFzCCFxMGCSqGSIb3DQEH
// SIG // AqCCFwQwghcAAgEDMQ8wDQYJYIZIAWUDBAIBBQAwggFY
// SIG // BgsqhkiG9w0BCRABBKCCAUcEggFDMIIBPwIBAQYKKwYB
// SIG // BAGEWQoDATAxMA0GCWCGSAFlAwQCAQUABCCgbPmGJj6l
// SIG // 1/qiZh2/wpDRT1ODqhcc7ozBSURSWxAuiAIGZfxlhN3b
// SIG // GBIyMDI0MDMyMjIwMTE1Ny40M1owBIACAfSggdikgdUw
// SIG // gdIxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5n
// SIG // dG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVN
// SIG // aWNyb3NvZnQgQ29ycG9yYXRpb24xLTArBgNVBAsTJE1p
// SIG // Y3Jvc29mdCBJcmVsYW5kIE9wZXJhdGlvbnMgTGltaXRl
// SIG // ZDEmMCQGA1UECxMdVGhhbGVzIFRTUyBFU046MkFENC00
// SIG // QjkyLUZBMDExJTAjBgNVBAMTHE1pY3Jvc29mdCBUaW1l
// SIG // LVN0YW1wIFNlcnZpY2WgghF7MIIHJzCCBQ+gAwIBAgIT
// SIG // MwAAAd6eSJ6WnyhEPQABAAAB3jANBgkqhkiG9w0BAQsF
// SIG // ADB8MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGlu
// SIG // Z3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMV
// SIG // TWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1N
// SIG // aWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDAeFw0y
// SIG // MzEwMTIxOTA3MTJaFw0yNTAxMTAxOTA3MTJaMIHSMQsw
// SIG // CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQ
// SIG // MA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9z
// SIG // b2Z0IENvcnBvcmF0aW9uMS0wKwYDVQQLEyRNaWNyb3Nv
// SIG // ZnQgSXJlbGFuZCBPcGVyYXRpb25zIExpbWl0ZWQxJjAk
// SIG // BgNVBAsTHVRoYWxlcyBUU1MgRVNOOjJBRDQtNEI5Mi1G
// SIG // QTAxMSUwIwYDVQQDExxNaWNyb3NvZnQgVGltZS1TdGFt
// SIG // cCBTZXJ2aWNlMIICIjANBgkqhkiG9w0BAQEFAAOCAg8A
// SIG // MIICCgKCAgEAtIH0HIX1QgOEDrEWs6eLD/GwOXyxKL2s
// SIG // 4I5dJI7hUxCOc0YCjlUfHSKKMwQwf0tjZJQgGRVBLQyX
// SIG // qRH5NqCRQ9toSnCOFDWamuFGAlP+OVKeJzjZUMCjR6fg
// SIG // kjrGdegChagrJJjz9E4gp2mmGAjs4lvhceTU/exfak1n
// SIG // fYsNjWS1yErX+FbI+VuVpcAdG7QTfKe/CtLz9tyisA07
// SIG // oOO7KzJL3NSav7DcfcAS9KCzZF64uPamQFx9bVQ8IW50
// SIG // t3sg9nZELih1BwQ+djXaPKlg+dLrJkCzSkumrQpEVTIH
// SIG // XHrHo5Tvey52Ic43XqYTSXostP06YajRL3gHGDc3/doT
// SIG // p9RudWh6ZVzsWQUu6bwqRlxtDtw4dIBYYnF0K+jk61S1
// SIG // F1Kp/zkWSUJcgiSDiybucz1OS1RV87SSnqTHubKyAPRC
// SIG // vHHr/mhqqfA5NYs3Mr4EKLUbudQPWm165e9Cnx8TUqlO
// SIG // Ocb/U4l56HAo00+Ma33xXQGaiBlN7dLEGQ545DIsD77k
// SIG // fKD8vryl74Otmhk9cloZT+IGIWYv66X86Ld3zfMsAeUd
// SIG // CYf9UY0F9HA/6LG+qHKT8R5vC5dUlj6tPJ9tF+6H2fQB
// SIG // oyGE3HGDq0YrJlLgQASIPGsX2YBkTLx7yt/p2Uohfl3d
// SIG // pAuj18N1rVlM7D5cBwC+Pb83cMtUZmUeceUCAwEAAaOC
// SIG // AUkwggFFMB0GA1UdDgQWBBRrMCZvGx5pqmB3HMrw6z6d
// SIG // o9ASyDAfBgNVHSMEGDAWgBSfpxVdAF5iXYP05dJlpxtT
// SIG // NRnpcjBfBgNVHR8EWDBWMFSgUqBQhk5odHRwOi8vd3d3
// SIG // Lm1pY3Jvc29mdC5jb20vcGtpb3BzL2NybC9NaWNyb3Nv
// SIG // ZnQlMjBUaW1lLVN0YW1wJTIwUENBJTIwMjAxMCgxKS5j
// SIG // cmwwbAYIKwYBBQUHAQEEYDBeMFwGCCsGAQUFBzAChlBo
// SIG // dHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpb3BzL2Nl
// SIG // cnRzL01pY3Jvc29mdCUyMFRpbWUtU3RhbXAlMjBQQ0El
// SIG // MjAyMDEwKDEpLmNydDAMBgNVHRMBAf8EAjAAMBYGA1Ud
// SIG // JQEB/wQMMAoGCCsGAQUFBwMIMA4GA1UdDwEB/wQEAwIH
// SIG // gDANBgkqhkiG9w0BAQsFAAOCAgEA4pTAexcNpwY69QiC
// SIG // zkcOA+zQtnWrIdLoLrB8qUtoPfq1l9ta3XH4YyJrNK7L
// SIG // 4azGJUfOSExb4WoryCu4tBY3+w4Jf58ZSBP0tPbVxEil
// SIG // xmPj9kUi/C2QFywLPVcRSxdg5IlQ+K1jsTxtuV2aaFhn
// SIG // b2n5dCkhywb+r5iOSoFb2bDSu7Ux/ExNCz0xMOIPbyAB
// SIG // Uas8Dc3KSJIKG92pLtVf78twTP1RvO2j/DbxYDwc4Ieo
// SIG // FNsNEeaI/swiP5JCYj1UhrJiwgZGO96WY1rQ69tT0IlL
// SIG // P818wSB/Y0cxlRhbwqpYSMiM98cgrFaU0xiG5Z9ZFIdk
// SIG // IrIgA0DRokviygdC3PNnYyc1+NhjznXAdiMaDBSP+GUt
// SIG // GBA7lLfRnHvwaoEp/KWnblo5Yn+o+EL4NczaBdqMhduX
// SIG // 6OkZxUA3C0UW6MIlF1lt4fVH5DjUWOAGDibc5MUMai3k
// SIG // NK5WRCCOS7uk5U+2V0TjpCUOD/ZaE+lNDFcfriw/UZ+Q
// SIG // DBS23qutkz88LBEbqCKtiadNEsuyJwGGhguH4QQWNW+J
// SIG // cAZOTqme7yPH/hY9a7SOzPvIXODzb8UyoKT3Arcu/IsD
// SIG // IMc34XFscDG2DBp3ugtA8zRYYRF0HW6Y8IiJixJ/+Pv0
// SIG // Sod2g3BBhE5Wb5lfXRFfefptGYCeyR42GLTCdVp5WiAs
// SIG // x0YP6eowggdxMIIFWaADAgECAhMzAAAAFcXna54Cm0mZ
// SIG // AAAAAAAVMA0GCSqGSIb3DQEBCwUAMIGIMQswCQYDVQQG
// SIG // EwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UE
// SIG // BxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENv
// SIG // cnBvcmF0aW9uMTIwMAYDVQQDEylNaWNyb3NvZnQgUm9v
// SIG // dCBDZXJ0aWZpY2F0ZSBBdXRob3JpdHkgMjAxMDAeFw0y
// SIG // MTA5MzAxODIyMjVaFw0zMDA5MzAxODMyMjVaMHwxCzAJ
// SIG // BgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAw
// SIG // DgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3Nv
// SIG // ZnQgQ29ycG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29m
// SIG // dCBUaW1lLVN0YW1wIFBDQSAyMDEwMIICIjANBgkqhkiG
// SIG // 9w0BAQEFAAOCAg8AMIICCgKCAgEA5OGmTOe0ciELeaLL
// SIG // 1yR5vQ7VgtP97pwHB9KpbE51yMo1V/YBf2xK4OK9uT4X
// SIG // YDP/XE/HZveVU3Fa4n5KWv64NmeFRiMMtY0Tz3cywBAY
// SIG // 6GB9alKDRLemjkZrBxTzxXb1hlDcwUTIcVxRMTegCjhu
// SIG // je3XD9gmU3w5YQJ6xKr9cmmvHaus9ja+NSZk2pg7uhp7
// SIG // M62AW36MEBydUv626GIl3GoPz130/o5Tz9bshVZN7928
// SIG // jaTjkY+yOSxRnOlwaQ3KNi1wjjHINSi947SHJMPgyY9+
// SIG // tVSP3PoFVZhtaDuaRr3tpK56KTesy+uDRedGbsoy1cCG
// SIG // MFxPLOJiss254o2I5JasAUq7vnGpF1tnYN74kpEeHT39
// SIG // IM9zfUGaRnXNxF803RKJ1v2lIH1+/NmeRd+2ci/bfV+A
// SIG // utuqfjbsNkz2K26oElHovwUDo9Fzpk03dJQcNIIP8BDy
// SIG // t0cY7afomXw/TNuvXsLz1dhzPUNOwTM5TI4CvEJoLhDq
// SIG // hFFG4tG9ahhaYQFzymeiXtcodgLiMxhy16cg8ML6EgrX
// SIG // Y28MyTZki1ugpoMhXV8wdJGUlNi5UPkLiWHzNgY1GIRH
// SIG // 29wb0f2y1BzFa/ZcUlFdEtsluq9QBXpsxREdcu+N+VLE
// SIG // hReTwDwV2xo3xwgVGD94q0W29R6HXtqPnhZyacaue7e3
// SIG // PmriLq0CAwEAAaOCAd0wggHZMBIGCSsGAQQBgjcVAQQF
// SIG // AgMBAAEwIwYJKwYBBAGCNxUCBBYEFCqnUv5kxJq+gpE8
// SIG // RjUpzxD/LwTuMB0GA1UdDgQWBBSfpxVdAF5iXYP05dJl
// SIG // pxtTNRnpcjBcBgNVHSAEVTBTMFEGDCsGAQQBgjdMg30B
// SIG // ATBBMD8GCCsGAQUFBwIBFjNodHRwOi8vd3d3Lm1pY3Jv
// SIG // c29mdC5jb20vcGtpb3BzL0RvY3MvUmVwb3NpdG9yeS5o
// SIG // dG0wEwYDVR0lBAwwCgYIKwYBBQUHAwgwGQYJKwYBBAGC
// SIG // NxQCBAweCgBTAHUAYgBDAEEwCwYDVR0PBAQDAgGGMA8G
// SIG // A1UdEwEB/wQFMAMBAf8wHwYDVR0jBBgwFoAU1fZWy4/o
// SIG // olxiaNE9lJBb186aGMQwVgYDVR0fBE8wTTBLoEmgR4ZF
// SIG // aHR0cDovL2NybC5taWNyb3NvZnQuY29tL3BraS9jcmwv
// SIG // cHJvZHVjdHMvTWljUm9vQ2VyQXV0XzIwMTAtMDYtMjMu
// SIG // Y3JsMFoGCCsGAQUFBwEBBE4wTDBKBggrBgEFBQcwAoY+
// SIG // aHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraS9jZXJ0
// SIG // cy9NaWNSb29DZXJBdXRfMjAxMC0wNi0yMy5jcnQwDQYJ
// SIG // KoZIhvcNAQELBQADggIBAJ1VffwqreEsH2cBMSRb4Z5y
// SIG // S/ypb+pcFLY+TkdkeLEGk5c9MTO1OdfCcTY/2mRsfNB1
// SIG // OW27DzHkwo/7bNGhlBgi7ulmZzpTTd2YurYeeNg2Lpyp
// SIG // glYAA7AFvonoaeC6Ce5732pvvinLbtg/SHUB2RjebYIM
// SIG // 9W0jVOR4U3UkV7ndn/OOPcbzaN9l9qRWqveVtihVJ9Ak
// SIG // vUCgvxm2EhIRXT0n4ECWOKz3+SmJw7wXsFSFQrP8DJ6L
// SIG // GYnn8AtqgcKBGUIZUnWKNsIdw2FzLixre24/LAl4FOmR
// SIG // sqlb30mjdAy87JGA0j3mSj5mO0+7hvoyGtmW9I/2kQH2
// SIG // zsZ0/fZMcm8Qq3UwxTSwethQ/gpY3UA8x1RtnWN0SCyx
// SIG // TkctwRQEcb9k+SS+c23Kjgm9swFXSVRk2XPXfx5bRAGO
// SIG // WhmRaw2fpCjcZxkoJLo4S5pu+yFUa2pFEUep8beuyOiJ
// SIG // Xk+d0tBMdrVXVAmxaQFEfnyhYWxz/gq77EFmPWn9y8FB
// SIG // SX5+k77L+DvktxW/tM4+pTFRhLy/AsGConsXHRWJjXD+
// SIG // 57XQKBqJC4822rpM+Zv/Cuk0+CQ1ZyvgDbjmjJnW4SLq
// SIG // 8CdCPSWU5nR0W2rRnj7tfqAxM328y+l7vzhwRNGQ8cir
// SIG // Ooo6CGJ/2XBjU02N7oJtpQUQwXEGahC0HVUzWLOhcGby
// SIG // oYIC1zCCAkACAQEwggEAoYHYpIHVMIHSMQswCQYDVQQG
// SIG // EwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UE
// SIG // BxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENv
// SIG // cnBvcmF0aW9uMS0wKwYDVQQLEyRNaWNyb3NvZnQgSXJl
// SIG // bGFuZCBPcGVyYXRpb25zIExpbWl0ZWQxJjAkBgNVBAsT
// SIG // HVRoYWxlcyBUU1MgRVNOOjJBRDQtNEI5Mi1GQTAxMSUw
// SIG // IwYDVQQDExxNaWNyb3NvZnQgVGltZS1TdGFtcCBTZXJ2
// SIG // aWNloiMKAQEwBwYFKw4DAhoDFQBooFKKzLjLzqmXxfLb
// SIG // YIlkTETa86CBgzCBgKR+MHwxCzAJBgNVBAYTAlVTMRMw
// SIG // EQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRt
// SIG // b25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRp
// SIG // b24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1w
// SIG // IFBDQSAyMDEwMA0GCSqGSIb3DQEBBQUAAgUA6aeMfDAi
// SIG // GA8yMDI0MDMyMjEyNTAwNFoYDzIwMjQwMzIzMTI1MDA0
// SIG // WjB3MD0GCisGAQQBhFkKBAExLzAtMAoCBQDpp4x8AgEA
// SIG // MAoCAQACAgCYAgH/MAcCAQACAhPOMAoCBQDpqN38AgEA
// SIG // MDYGCisGAQQBhFkKBAIxKDAmMAwGCisGAQQBhFkKAwKg
// SIG // CjAIAgEAAgMHoSChCjAIAgEAAgMBhqAwDQYJKoZIhvcN
// SIG // AQEFBQADgYEAY9GaxIrNRbBJSbrI+mYyMe0GLOkXcGgP
// SIG // BnzPCuyeIhTcEPuK1tFL09wxwNwsPNejOgMXb1T2l2Fr
// SIG // 9wz4Ru9n2UpSLDzGlZrGDWm32bU5NHFjCdvJYYoCdguN
// SIG // mRzFpXojumT/JIMai/QVKpfdZaOOdBXZ6N/5N9errCBa
// SIG // hiDm7/YxggQNMIIECQIBATCBkzB8MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGltZS1T
// SIG // dGFtcCBQQ0EgMjAxMAITMwAAAd6eSJ6WnyhEPQABAAAB
// SIG // 3jANBglghkgBZQMEAgEFAKCCAUowGgYJKoZIhvcNAQkD
// SIG // MQ0GCyqGSIb3DQEJEAEEMC8GCSqGSIb3DQEJBDEiBCB+
// SIG // CO8NwnctF56DMRVIMr0jI1mMB3mDrJsQmww8teovhjCB
// SIG // +gYLKoZIhvcNAQkQAi8xgeowgecwgeQwgb0EII4+I58N
// SIG // wV4QEEkCf+YLcyCtPnD9TbPzUtgPjgdzfh17MIGYMIGA
// SIG // pH4wfDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
// SIG // bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoT
// SIG // FU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMd
// SIG // TWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTACEzMA
// SIG // AAHenkielp8oRD0AAQAAAd4wIgQg4qHORPI2/wFA+OSb
// SIG // Q76Lf57KWwSGXtFMNVp7JLW2OOEwDQYJKoZIhvcNAQEL
// SIG // BQAEggIAP9nC2QdUzo5jGtrqxHZo2wYHtr2wuX+pszF8
// SIG // kKw63K7WkcUV52+tmJ9k83tNcopvC8KPiZemCWf9ri3n
// SIG // JM+z+wM0rHHDRK37NvywXymCRvnjQziB49TNjCiwuOEX
// SIG // TxxGaTjaxMnu1mZJYc6OpCjFeFJyxcLsAxqYL9d4wrFA
// SIG // i2UJnOW4BeN406nre41Zvwb6o1xDbwVstGxCd+XHI2et
// SIG // ZR7or+7ojhS1gii7dM0sLTcAifAognh3dfNQhPTIXRS1
// SIG // L6suJ1JJN/M1Tmu5Ieo/OHF6MEgAOp7Z+OSeOyeJWFv6
// SIG // 3J524tAPDEffCH7QbM+niVExIwLnFc9oHR1zcRZx7RGH
// SIG // N2QRy/sMGjF8jlHsb0R0z2+RFX9UlBjjjNNukTlBndW8
// SIG // kFmAMmN9FikgFhev8fQ5EJbF/d3CghvGtyvXI9JVGMlV
// SIG // 7QYrqSqAlGtsS6mYCfjE8lOTTl3XdKKovOMDc8VDF2L+
// SIG // A1eWv3204SNQkgTXYmr0XN46ct0En+wIrDeNY0imrPpG
// SIG // 3BDwxywyeIlLI29ULAlDc58YVcCYie5OPiceArmwy1pQ
// SIG // fxJmHZCSH9GU8/BSvdoXdNqZ9mgH0B0bR/NhbGrtjWTU
// SIG // h8H793+iSWUT3w9Urb2oXOKwbv9eJDLIVZIvKhKvd/VO
// SIG // euwqrHHsIndT3W99cePsu5Sy8MuVhss=
// SIG // End signature block
