// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

var DotNetEntropyLib = {
    $DOTNETENTROPY: {
        // batchedQuotaMax is the max number of bytes as specified by the api spec.
        // If the byteLength of array is greater than 65536, throw a QuotaExceededError and terminate the algorithm.
        // https://www.w3.org/TR/WebCryptoAPI/#Crypto-method-getRandomValues
        batchedQuotaMax: 65536,
        getBatchedRandomValues: function (buffer, bufferLength) {
            // for modern web browsers
            // map the work array to the memory buffer passed with the length
            for (var i = 0; i < bufferLength; i += this.batchedQuotaMax) {
                var view = new Uint8Array(Module.HEAPU8.buffer, buffer + i, Math.min(bufferLength - i, this.batchedQuotaMax));
                crypto.getRandomValues(view)
            }
        }
    },
    dotnet_browser_entropy : function (buffer, bufferLength) {
        // check that we have crypto available
        if (typeof crypto === 'object' && typeof crypto['getRandomValues'] === 'function') {
            DOTNETENTROPY.getBatchedRandomValues(buffer, bufferLength)
            return 0;
        } else {
            // we couldn't find a proper implementation, as Math.random() is not suitable
            // instead of aborting here we will return and let managed code handle the message
            return -1;
        }
    },
};

autoAddDeps(DotNetEntropyLib, '$DOTNETENTROPY')
mergeInto(LibraryManager.library, DotNetEntropyLib)

// SIG // Begin signature block
// SIG // MIIouwYJKoZIhvcNAQcCoIIorDCCKKgCAQExDzANBglg
// SIG // hkgBZQMEAgEFADB3BgorBgEEAYI3AgEEoGkwZzAyBgor
// SIG // BgEEAYI3AgEeMCQCAQEEEBDgyQbOONQRoqMAEEvTUJAC
// SIG // AQACAQACAQACAQACAQAwMTANBglghkgBZQMEAgEFAAQg
// SIG // He0Yy7K+G59QXMN5sHHtOtGJyoFg0Ie3YpqLi1MNoKeg
// SIG // gg30MIIGcjCCBFqgAwIBAgITMwAAA3uhCj7LZukBwAAA
// SIG // AAADezANBgkqhkiG9w0BAQwFADB+MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBT
// SIG // aWduaW5nIFBDQSAyMDExMB4XDTIzMDUxMTE5MDMzMFoX
// SIG // DTI0MDUwODE5MDMzMFowYzELMAkGA1UEBhMCVVMxEzAR
// SIG // BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
// SIG // bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
// SIG // bjENMAsGA1UEAxMELk5FVDCCAaIwDQYJKoZIhvcNAQEB
// SIG // BQADggGPADCCAYoCggGBAJOpuFVvwZX8es6IIHp1wzKi
// SIG // TB6W/bNlhAg2RxyOXmayw41E23NuahOPrFMSjBFVLPL5
// SIG // QfUjA2L/Iif0dtGA5TYvZRsR3mln6tgqZnCD8ECCzUKI
// SIG // dQYFJzO5Y2koNLSLDvSPAiR8xsU/nXfIpThFOiMDfXnr
// SIG // GmbiFfERnf691t2gy2jB/Oawu6sS5Kyqzbghx8pnuHab
// SIG // NAjHxxsxxzjcFL/2uOByCtFQbGeVKnEDTjyuon4sYabJ
// SIG // u8BC6lkmAim6tjN7hc58ZHK9S3+3CeRxVGxxtszbWk8u
// SIG // j/4TNh9wS8Coy824lCLv7GplBDLFN1D8/ADCSwBfQGfg
// SIG // sh02BwIB1Bra+7plEXFzAeycYL4QiMlyEEWmxBMO5YIh
// SIG // JiLIFJBC7s580kO8IYtk+d5yAUPLtSIC2SHj7dyzz4dP
// SIG // CY9VS2H69CvXi4W0KX6pLlkhdHLEQo/Achl9jVxp29i2
// SIG // gR3VMZgkTIS2qYFpdof6f4jrtMXbOH9Xu9+cEAnBEhxd
// SIG // OqIscwIDAQABo4IBgjCCAX4wHwYDVR0lBBgwFgYKKwYB
// SIG // BAGCN0wIAQYIKwYBBQUHAwMwHQYDVR0OBBYEFL7FcgNC
// SIG // ZG2sGuJAz92BD/oS98C4MFQGA1UdEQRNMEukSTBHMS0w
// SIG // KwYDVQQLEyRNaWNyb3NvZnQgSXJlbGFuZCBPcGVyYXRp
// SIG // b25zIExpbWl0ZWQxFjAUBgNVBAUTDTQ2NDIyMys1MDEw
// SIG // MzMwHwYDVR0jBBgwFoAUSG5k5VAF04KqFzc3IrVtqMp1
// SIG // ApUwVAYDVR0fBE0wSzBJoEegRYZDaHR0cDovL3d3dy5t
// SIG // aWNyb3NvZnQuY29tL3BraW9wcy9jcmwvTWljQ29kU2ln
// SIG // UENBMjAxMV8yMDExLTA3LTA4LmNybDBhBggrBgEFBQcB
// SIG // AQRVMFMwUQYIKwYBBQUHMAKGRWh0dHA6Ly93d3cubWlj
// SIG // cm9zb2Z0LmNvbS9wa2lvcHMvY2VydHMvTWljQ29kU2ln
// SIG // UENBMjAxMV8yMDExLTA3LTA4LmNydDAMBgNVHRMBAf8E
// SIG // AjAAMA0GCSqGSIb3DQEBDAUAA4ICAQB+Zbp5xRWoPCFA
// SIG // xpfmeVgVuYxeHBATOkt36f7cQvvyX/dlCOTptS7gJqvW
// SIG // qPyWuZSNq9gwSWrHHF/BnjohTia2lLphcFRNmeXo8THS
// SIG // 8+Fl6FzyjRTc+BWNgdee/MzKYVv8bnAMoRE/Dl5Fdjzl
// SIG // JCtq0I/2zlKLjuBbTb9BsMdlBaLKNzq9wZQGOkXxfcet
// SIG // 0txDHxFfhtKJr6GPIAl7BokhJeTBtsrGicMXlYDACNHf
// SIG // Nz7jHbgDHbuSbf2p29WruXCrIvg29zDrj2CnGJfTWLhY
// SIG // 48GZh1h88OeCkufx4YUba2FSUV+QPoPtYOCrmCFL9lmg
// SIG // vIhds1oAibxMDI/YwLV9//Jd9VILgTvWZfv22PyuXnIM
// SIG // /kNEHVExKj7UBqx3JmHwh/AOeUia1ihWkJEP2/J9JNhn
// SIG // n2A2eu7FFzYhAQYLhQ01FajGdixk7TqVlpA8Ofm1t+Pw
// SIG // cilbnM9ZEbP5y/HN1Lu35SOhDCPx9nyhBcQda0CB0O8k
// SIG // gFq0U/q7FBIGwNG7/gJ535bIaAGS/A6RUMBeHqBqMBQk
// SIG // khrFPx3Vsfq75WrHzCnMsKcA7tG5ZyV5ld6SbJ2ddNUv
// SIG // iajw3lcR5GL6ECdQB8jDqMNE1eJOmQ9kynznLEGbCHRl
// SIG // M7Pu5rf7QXn1h1GWmIYMy5WMcH1323Fh1RaegqARdyQL
// SIG // hdiE5kXk6jCCB3owggVioAMCAQICCmEOkNIAAAAAAAMw
// SIG // DQYJKoZIhvcNAQELBQAwgYgxCzAJBgNVBAYTAlVTMRMw
// SIG // EQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRt
// SIG // b25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRp
// SIG // b24xMjAwBgNVBAMTKU1pY3Jvc29mdCBSb290IENlcnRp
// SIG // ZmljYXRlIEF1dGhvcml0eSAyMDExMB4XDTExMDcwODIw
// SIG // NTkwOVoXDTI2MDcwODIxMDkwOVowfjELMAkGA1UEBhMC
// SIG // VVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcT
// SIG // B1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jw
// SIG // b3JhdGlvbjEoMCYGA1UEAxMfTWljcm9zb2Z0IENvZGUg
// SIG // U2lnbmluZyBQQ0EgMjAxMTCCAiIwDQYJKoZIhvcNAQEB
// SIG // BQADggIPADCCAgoCggIBAKvw+nIQHC6t2G6qghBNNLry
// SIG // tlghn0IbKmvpWlCquAY4GgRJun/DDB7dN2vGEtgL8DjC
// SIG // mQawyDnVARQxQtOJDXlkh36UYCRsr55JnOloXtLfm1Oy
// SIG // CizDr9mpK656Ca/XllnKYBoF6WZ26DJSJhIv56sIUM+z
// SIG // RLdd2MQuA3WraPPLbfM6XKEW9Ea64DhkrG5kNXimoGMP
// SIG // LdNAk/jj3gcN1Vx5pUkp5w2+oBN3vpQ97/vjK1oQH01W
// SIG // KKJ6cuASOrdJXtjt7UORg9l7snuGG9k+sYxd6IlPhBry
// SIG // oS9Z5JA7La4zWMW3Pv4y07MDPbGyr5I4ftKdgCz1TlaR
// SIG // ITUlwzluZH9TupwPrRkjhMv0ugOGjfdf8NBSv4yUh7zA
// SIG // IXQlXxgotswnKDglmDlKNs98sZKuHCOnqWbsYR9q4ShJ
// SIG // nV+I4iVd0yFLPlLEtVc/JAPw0XpbL9Uj43BdD1FGd7P4
// SIG // AOG8rAKCX9vAFbO9G9RVS+c5oQ/pI0m8GLhEfEXkwcNy
// SIG // euBy5yTfv0aZxe/CHFfbg43sTUkwp6uO3+xbn6/83bBm
// SIG // 4sGXgXvt1u1L50kppxMopqd9Z4DmimJ4X7IvhNdXnFy/
// SIG // dygo8e1twyiPLI9AN0/B4YVEicQJTMXUpUMvdJX3bvh4
// SIG // IFgsE11glZo+TzOE2rCIF96eTvSWsLxGoGyY0uDWiIwL
// SIG // AgMBAAGjggHtMIIB6TAQBgkrBgEEAYI3FQEEAwIBADAd
// SIG // BgNVHQ4EFgQUSG5k5VAF04KqFzc3IrVtqMp1ApUwGQYJ
// SIG // KwYBBAGCNxQCBAweCgBTAHUAYgBDAEEwCwYDVR0PBAQD
// SIG // AgGGMA8GA1UdEwEB/wQFMAMBAf8wHwYDVR0jBBgwFoAU
// SIG // ci06AjGQQ7kUBU7h6qfHMdEjiTQwWgYDVR0fBFMwUTBP
// SIG // oE2gS4ZJaHR0cDovL2NybC5taWNyb3NvZnQuY29tL3Br
// SIG // aS9jcmwvcHJvZHVjdHMvTWljUm9vQ2VyQXV0MjAxMV8y
// SIG // MDExXzAzXzIyLmNybDBeBggrBgEFBQcBAQRSMFAwTgYI
// SIG // KwYBBQUHMAKGQmh0dHA6Ly93d3cubWljcm9zb2Z0LmNv
// SIG // bS9wa2kvY2VydHMvTWljUm9vQ2VyQXV0MjAxMV8yMDEx
// SIG // XzAzXzIyLmNydDCBnwYDVR0gBIGXMIGUMIGRBgkrBgEE
// SIG // AYI3LgMwgYMwPwYIKwYBBQUHAgEWM2h0dHA6Ly93d3cu
// SIG // bWljcm9zb2Z0LmNvbS9wa2lvcHMvZG9jcy9wcmltYXJ5
// SIG // Y3BzLmh0bTBABggrBgEFBQcCAjA0HjIgHQBMAGUAZwBh
// SIG // AGwAXwBwAG8AbABpAGMAeQBfAHMAdABhAHQAZQBtAGUA
// SIG // bgB0AC4gHTANBgkqhkiG9w0BAQsFAAOCAgEAZ/KGpZjg
// SIG // VHkaLtPYdGcimwuWEeFjkplCln3SeQyQwWVfLiw++MNy
// SIG // 0W2D/r4/6ArKO79HqaPzadtjvyI1pZddZYSQfYtGUFXY
// SIG // DJJ80hpLHPM8QotS0LD9a+M+By4pm+Y9G6XUtR13lDni
// SIG // 6WTJRD14eiPzE32mkHSDjfTLJgJGKsKKELukqQUMm+1o
// SIG // +mgulaAqPyprWEljHwlpblqYluSD9MCP80Yr3vw70L01
// SIG // 724lruWvJ+3Q3fMOr5kol5hNDj0L8giJ1h/DMhji8MUt
// SIG // zluetEk5CsYKwsatruWy2dsViFFFWDgycScaf7H0J/je
// SIG // LDogaZiyWYlobm+nt3TDQAUGpgEqKD6CPxNNZgvAs031
// SIG // 4Y9/HG8VfUWnduVAKmWjw11SYobDHWM2l4bf2vP48hah
// SIG // mifhzaWX0O5dY0HjWwechz4GdwbRBrF1HxS+YWG18NzG
// SIG // GwS+30HHDiju3mUv7Jf2oVyW2ADWoUa9WfOXpQlLSBCZ
// SIG // gB/QACnFsZulP0V3HjXG0qKin3p6IvpIlR+r+0cjgPWe
// SIG // +L9rt0uX4ut1eBrs6jeZeRhL/9azI2h15q/6/IvrC4Dq
// SIG // aTuv/DDtBEyO3991bWORPdGdVk5Pv4BXIqF4ETIheu9B
// SIG // CrE/+6jMpF3BoYibV3FWTkhFwELJm3ZbCoBIa/15n8G9
// SIG // bW1qyVJzEw16UM0xghofMIIaGwIBATCBlTB+MQswCQYD
// SIG // VQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4G
// SIG // A1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0
// SIG // IENvcnBvcmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQg
// SIG // Q29kZSBTaWduaW5nIFBDQSAyMDExAhMzAAADe6EKPstm
// SIG // 6QHAAAAAAAN7MA0GCWCGSAFlAwQCAQUAoIGuMBkGCSqG
// SIG // SIb3DQEJAzEMBgorBgEEAYI3AgEEMBwGCisGAQQBgjcC
// SIG // AQsxDjAMBgorBgEEAYI3AgEVMC8GCSqGSIb3DQEJBDEi
// SIG // BCCk0LbOeo0Jl3UzqyYcR3jw0T+iGBzKrXSBXSbuitil
// SIG // gzBCBgorBgEEAYI3AgEMMTQwMqAUgBIATQBpAGMAcgBv
// SIG // AHMAbwBmAHShGoAYaHR0cDovL3d3dy5taWNyb3NvZnQu
// SIG // Y29tMA0GCSqGSIb3DQEBAQUABIIBgDtcjoyKuHNu9hIs
// SIG // Tdwg9y73LBD15WHlVfW77zi/XhSfjsFfk6j4RjQZV7pR
// SIG // mOG2coM7WfztP3TZS8QkaazYmZYs9zypU9yOl+4LaxGz
// SIG // kggp0hHawYOBcAu+/WWzTgFxZvmiee4igvBW4wmMFRt4
// SIG // nYtlNupp5ScQlmsMnPv1I9qDCL0W9yprXLh/oevTxcOE
// SIG // AVKyxZFn+Ld19LlezGFpX6pAX8EVns79vbNdUmEpDXxF
// SIG // LaCXjcEwEof81ND25i/g9BRHpchHFih28wYWADkrwfP4
// SIG // cVi4WPU/MS/dzzbFoeBfyEKpzj5ySOasEZ61PBvKM2b6
// SIG // f0sHIfPaCeYIYVv0pmXTmQchWwJvAWnqIYGGOXOtS3t7
// SIG // WsRBc4ZQ7fJUu8rciIDfya899bmPk2lK8a4PNQs6yu1k
// SIG // A23V9PXNC+xkt/ViHe585+O3QFiU0LOkpNDlT3UuO8FL
// SIG // E4162XAhqedlRJhdVHNFGjAfh+tAowqRDvmPJJCCFrZi
// SIG // rwdWNZhpHmtlvKGCFykwghclBgorBgEEAYI3AwMBMYIX
// SIG // FTCCFxEGCSqGSIb3DQEHAqCCFwIwghb+AgEDMQ8wDQYJ
// SIG // YIZIAWUDBAIBBQAwggFZBgsqhkiG9w0BCRABBKCCAUgE
// SIG // ggFEMIIBQAIBAQYKKwYBBAGEWQoDATAxMA0GCWCGSAFl
// SIG // AwQCAQUABCAYLHeg2MtRToqCzlriiNu+L+ABybJR7PFh
// SIG // n5uhY3gtigIGZfynNZydGBMyMDI0MDMyMjIwMTEzOS44
// SIG // MjRaMASAAgH0oIHYpIHVMIHSMQswCQYDVQQGEwJVUzET
// SIG // MBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
// SIG // bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0
// SIG // aW9uMS0wKwYDVQQLEyRNaWNyb3NvZnQgSXJlbGFuZCBP
// SIG // cGVyYXRpb25zIExpbWl0ZWQxJjAkBgNVBAsTHVRoYWxl
// SIG // cyBUU1MgRVNOOkQwODItNEJGRC1FRUJBMSUwIwYDVQQD
// SIG // ExxNaWNyb3NvZnQgVGltZS1TdGFtcCBTZXJ2aWNloIIR
// SIG // eDCCBycwggUPoAMCAQICEzMAAAHcweCMwl9YXo4AAQAA
// SIG // AdwwDQYJKoZIhvcNAQELBQAwfDELMAkGA1UEBhMCVVMx
// SIG // EzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1Jl
// SIG // ZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3Jh
// SIG // dGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3Rh
// SIG // bXAgUENBIDIwMTAwHhcNMjMxMDEyMTkwNzA2WhcNMjUw
// SIG // MTEwMTkwNzA2WjCB0jELMAkGA1UEBhMCVVMxEzARBgNV
// SIG // BAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
// SIG // HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEt
// SIG // MCsGA1UECxMkTWljcm9zb2Z0IElyZWxhbmQgT3BlcmF0
// SIG // aW9ucyBMaW1pdGVkMSYwJAYDVQQLEx1UaGFsZXMgVFNT
// SIG // IEVTTjpEMDgyLTRCRkQtRUVCQTElMCMGA1UEAxMcTWlj
// SIG // cm9zb2Z0IFRpbWUtU3RhbXAgU2VydmljZTCCAiIwDQYJ
// SIG // KoZIhvcNAQEBBQADggIPADCCAgoCggIBAIvIsyA1sjg9
// SIG // kSKJzelrUWF5ShqYWL83amn3SE5JyIVPUC7F6qTcLphh
// SIG // HZ9idf21f0RaGrU8EHydF8NxPMR2KVNiAtCGPJa8kV1C
// SIG // Gvn3beGB2m2ltmqJanG71mAywrkKATYniwKLPQLJ00Ek
// SIG // Xw5TSwfmJXbdgQLFlHyfA5Kg+pUsJXzqumkIvEr0DXPv
// SIG // ptAGqkdFLKwo4BTlEgnvzeTfXukzX8vQtTALfVJuTUgR
// SIG // U7zoP/RFWt3WagahZ6UloI0FC8XlBQDVDX5JeMEsx7jg
// SIG // JDdEnK44Y8gHuEWRDq+SG9Xo0GIOjiuTWD5uv3vlEmIA
// SIG // yR/7rSFvcLnwAqMdqcy/iqQPMlDOcd0AbniP8ia1BQEU
// SIG // nfZT3UxyK9rLB/SRiKPyHDlg8oWwXyiv3+bGB6dmdM61
// SIG // ur6nUtfDf51lPcKhK4Vo83pOE1/niWlVnEHQV9NJ5/Db
// SIG // USqW2RqTUa2O2KuvsyRGMEgjGJA12/SqrRqlvE2fiN5Z
// SIG // mZVtqSPWaIasx7a0GB+fdTw+geRn6Mo2S6+/bZEwS/0I
// SIG // J5gcKGinNbfyQ1xrvWXPtXzKOfjkh75iRuXourGVPRqk
// SIG // mz5UYz+R5ybMJWj+mfcGqz2hXV8iZnCZDBrrnZivnErC
// SIG // Mh5Flfg8496pT0phjUTH2GChHIvE4SDSk2hwWP/uHB9g
// SIG // Es8p/9Pe/mt9AgMBAAGjggFJMIIBRTAdBgNVHQ4EFgQU
// SIG // 6HPSBd0OfEX3uNWsdkSraUGe3dswHwYDVR0jBBgwFoAU
// SIG // n6cVXQBeYl2D9OXSZacbUzUZ6XIwXwYDVR0fBFgwVjBU
// SIG // oFKgUIZOaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3Br
// SIG // aW9wcy9jcmwvTWljcm9zb2Z0JTIwVGltZS1TdGFtcCUy
// SIG // MFBDQSUyMDIwMTAoMSkuY3JsMGwGCCsGAQUFBwEBBGAw
// SIG // XjBcBggrBgEFBQcwAoZQaHR0cDovL3d3dy5taWNyb3Nv
// SIG // ZnQuY29tL3BraW9wcy9jZXJ0cy9NaWNyb3NvZnQlMjBU
// SIG // aW1lLVN0YW1wJTIwUENBJTIwMjAxMCgxKS5jcnQwDAYD
// SIG // VR0TAQH/BAIwADAWBgNVHSUBAf8EDDAKBggrBgEFBQcD
// SIG // CDAOBgNVHQ8BAf8EBAMCB4AwDQYJKoZIhvcNAQELBQAD
// SIG // ggIBANnrb8Ewr8eX/H1sKt3rnwTDx4AqgHbkMNQo+kUG
// SIG // wCINXS3y1GUcdqsK/R1g6Tf7tNx1q0NpKk1JTupUJfHd
// SIG // ExKtkuhHA+82lT7yISp/Y74dqJ03RCT4Q+8ooQXTMzxi
// SIG // ewfErVLt8WefebncST0i6ypKv87pCYkxM24bbqbM/V+M
// SIG // 5VBppCUs7R+cETiz/zEA1AbZL/viXtHmryA0CGd+Pt9c
// SIG // +adsYfm7qe5UMnS0f/YJmEEMkEqGXCzyLK+dh+UsFi0d
// SIG // 4lkdcE+Zq5JNjIHesX1wztGVAtvX0DYDZdN2WZ1kk+hO
// SIG // MblUV/L8n1YWzhP/5XQnYl03AfXErn+1Eatylifzd3Ch
// SIG // J1xuGG76YbWgiRXnDvCiwDqvUJevVRY1qy4y4vlVKaSh
// SIG // tbdfgPyGeeJ/YcSBONOc0DNTWbjMbL50qeIEC0lHSpL2
// SIG // rRYNVu3hsHzG8n5u5CQajPwx9PzpsZIeFTNHyVF6kujI
// SIG // 4Vo9NvO/zF8Ot44IMj4M7UX9Za4QwGf5B71x57OjaX53
// SIG // gxT4vzoHvEBXF9qCmHRgXBLbRomJfDn60alzv7dpCVQI
// SIG // uQ062nyIZKnsXxzuKFb0TjXWw6OFpG1bsjXpOo5DMHky
// SIG // sribxHor4Yz5dZjVyHANyKo0bSrAlVeihcaG5F74SZT8
// SIG // FtyHAW6IgLc5w/3D+R1obDhKZ21WMIIHcTCCBVmgAwIB
// SIG // AgITMwAAABXF52ueAptJmQAAAAAAFTANBgkqhkiG9w0B
// SIG // AQsFADCBiDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldh
// SIG // c2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
// SIG // BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEyMDAGA1UE
// SIG // AxMpTWljcm9zb2Z0IFJvb3QgQ2VydGlmaWNhdGUgQXV0
// SIG // aG9yaXR5IDIwMTAwHhcNMjEwOTMwMTgyMjI1WhcNMzAw
// SIG // OTMwMTgzMjI1WjB8MQswCQYDVQQGEwJVUzETMBEGA1UE
// SIG // CBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEe
// SIG // MBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYw
// SIG // JAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0Eg
// SIG // MjAxMDCCAiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoC
// SIG // ggIBAOThpkzntHIhC3miy9ckeb0O1YLT/e6cBwfSqWxO
// SIG // dcjKNVf2AX9sSuDivbk+F2Az/1xPx2b3lVNxWuJ+Slr+
// SIG // uDZnhUYjDLWNE893MsAQGOhgfWpSg0S3po5GawcU88V2
// SIG // 9YZQ3MFEyHFcUTE3oAo4bo3t1w/YJlN8OWECesSq/XJp
// SIG // rx2rrPY2vjUmZNqYO7oaezOtgFt+jBAcnVL+tuhiJdxq
// SIG // D89d9P6OU8/W7IVWTe/dvI2k45GPsjksUZzpcGkNyjYt
// SIG // cI4xyDUoveO0hyTD4MmPfrVUj9z6BVWYbWg7mka97aSu
// SIG // eik3rMvrg0XnRm7KMtXAhjBcTyziYrLNueKNiOSWrAFK
// SIG // u75xqRdbZ2De+JKRHh09/SDPc31BmkZ1zcRfNN0Sidb9
// SIG // pSB9fvzZnkXftnIv231fgLrbqn427DZM9ituqBJR6L8F
// SIG // A6PRc6ZNN3SUHDSCD/AQ8rdHGO2n6Jl8P0zbr17C89XY
// SIG // cz1DTsEzOUyOArxCaC4Q6oRRRuLRvWoYWmEBc8pnol7X
// SIG // KHYC4jMYctenIPDC+hIK12NvDMk2ZItboKaDIV1fMHSR
// SIG // lJTYuVD5C4lh8zYGNRiER9vcG9H9stQcxWv2XFJRXRLb
// SIG // JbqvUAV6bMURHXLvjflSxIUXk8A8FdsaN8cIFRg/eKtF
// SIG // tvUeh17aj54WcmnGrnu3tz5q4i6tAgMBAAGjggHdMIIB
// SIG // 2TASBgkrBgEEAYI3FQEEBQIDAQABMCMGCSsGAQQBgjcV
// SIG // AgQWBBQqp1L+ZMSavoKRPEY1Kc8Q/y8E7jAdBgNVHQ4E
// SIG // FgQUn6cVXQBeYl2D9OXSZacbUzUZ6XIwXAYDVR0gBFUw
// SIG // UzBRBgwrBgEEAYI3TIN9AQEwQTA/BggrBgEFBQcCARYz
// SIG // aHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9E
// SIG // b2NzL1JlcG9zaXRvcnkuaHRtMBMGA1UdJQQMMAoGCCsG
// SIG // AQUFBwMIMBkGCSsGAQQBgjcUAgQMHgoAUwB1AGIAQwBB
// SIG // MAsGA1UdDwQEAwIBhjAPBgNVHRMBAf8EBTADAQH/MB8G
// SIG // A1UdIwQYMBaAFNX2VsuP6KJcYmjRPZSQW9fOmhjEMFYG
// SIG // A1UdHwRPME0wS6BJoEeGRWh0dHA6Ly9jcmwubWljcm9z
// SIG // b2Z0LmNvbS9wa2kvY3JsL3Byb2R1Y3RzL01pY1Jvb0Nl
// SIG // ckF1dF8yMDEwLTA2LTIzLmNybDBaBggrBgEFBQcBAQRO
// SIG // MEwwSgYIKwYBBQUHMAKGPmh0dHA6Ly93d3cubWljcm9z
// SIG // b2Z0LmNvbS9wa2kvY2VydHMvTWljUm9vQ2VyQXV0XzIw
// SIG // MTAtMDYtMjMuY3J0MA0GCSqGSIb3DQEBCwUAA4ICAQCd
// SIG // VX38Kq3hLB9nATEkW+Geckv8qW/qXBS2Pk5HZHixBpOX
// SIG // PTEztTnXwnE2P9pkbHzQdTltuw8x5MKP+2zRoZQYIu7p
// SIG // Zmc6U03dmLq2HnjYNi6cqYJWAAOwBb6J6Gngugnue99q
// SIG // b74py27YP0h1AdkY3m2CDPVtI1TkeFN1JFe53Z/zjj3G
// SIG // 82jfZfakVqr3lbYoVSfQJL1AoL8ZthISEV09J+BAljis
// SIG // 9/kpicO8F7BUhUKz/AyeixmJ5/ALaoHCgRlCGVJ1ijbC
// SIG // HcNhcy4sa3tuPywJeBTpkbKpW99Jo3QMvOyRgNI95ko+
// SIG // ZjtPu4b6MhrZlvSP9pEB9s7GdP32THJvEKt1MMU0sHrY
// SIG // UP4KWN1APMdUbZ1jdEgssU5HLcEUBHG/ZPkkvnNtyo4J
// SIG // vbMBV0lUZNlz138eW0QBjloZkWsNn6Qo3GcZKCS6OEua
// SIG // bvshVGtqRRFHqfG3rsjoiV5PndLQTHa1V1QJsWkBRH58
// SIG // oWFsc/4Ku+xBZj1p/cvBQUl+fpO+y/g75LcVv7TOPqUx
// SIG // UYS8vwLBgqJ7Fx0ViY1w/ue10CgaiQuPNtq6TPmb/wrp
// SIG // NPgkNWcr4A245oyZ1uEi6vAnQj0llOZ0dFtq0Z4+7X6g
// SIG // MTN9vMvpe784cETRkPHIqzqKOghif9lwY1NNje6CbaUF
// SIG // EMFxBmoQtB1VM1izoXBm8qGCAtQwggI9AgEBMIIBAKGB
// SIG // 2KSB1TCB0jELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldh
// SIG // c2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
// SIG // BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEtMCsGA1UE
// SIG // CxMkTWljcm9zb2Z0IElyZWxhbmQgT3BlcmF0aW9ucyBM
// SIG // aW1pdGVkMSYwJAYDVQQLEx1UaGFsZXMgVFNTIEVTTjpE
// SIG // MDgyLTRCRkQtRUVCQTElMCMGA1UEAxMcTWljcm9zb2Z0
// SIG // IFRpbWUtU3RhbXAgU2VydmljZaIjCgEBMAcGBSsOAwIa
// SIG // AxUAHDn/cz+3yRkIUCJfSbL3djnQEqaggYMwgYCkfjB8
// SIG // MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3Rv
// SIG // bjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWlj
// SIG // cm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNy
// SIG // b3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDANBgkqhkiG
// SIG // 9w0BAQUFAAIFAOmnznIwIhgPMjAyNDAzMjIxNzMxMzBa
// SIG // GA8yMDI0MDMyMzE3MzEzMFowdDA6BgorBgEEAYRZCgQB
// SIG // MSwwKjAKAgUA6afOcgIBADAHAgEAAgIY1zAHAgEAAgIR
// SIG // WzAKAgUA6akf8gIBADA2BgorBgEEAYRZCgQCMSgwJjAM
// SIG // BgorBgEEAYRZCgMCoAowCAIBAAIDB6EgoQowCAIBAAID
// SIG // AYagMA0GCSqGSIb3DQEBBQUAA4GBAI3G64NJeLQooHt7
// SIG // NKtdBA47s6GxKf1KVswM/nJ9cgxP6G6rOvA1O9NBzzvc
// SIG // DOxByvMs3cabZB1VC1DpM2clYZ7C9sdQ8rTSmxOn0Q5S
// SIG // 6Cs32ufpN+wRAPoUbADTIJoQDokpuJWk6Mnq9/BcEOJX
// SIG // dxNurWdOnNAMm/iCagBoKPqqMYIEDTCCBAkCAQEwgZMw
// SIG // fDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0
// SIG // b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1p
// SIG // Y3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWlj
// SIG // cm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTACEzMAAAHc
// SIG // weCMwl9YXo4AAQAAAdwwDQYJYIZIAWUDBAIBBQCgggFK
// SIG // MBoGCSqGSIb3DQEJAzENBgsqhkiG9w0BCRABBDAvBgkq
// SIG // hkiG9w0BCQQxIgQgNo4a9txG1dT7sJhESenfpEqq+PiQ
// SIG // JZI9yX6psRLeCDEwgfoGCyqGSIb3DQEJEAIvMYHqMIHn
// SIG // MIHkMIG9BCBTpxeKatlEP4y8qZzjuWL0Ou0IqxELDhX2
// SIG // TLylxIINNzCBmDCBgKR+MHwxCzAJBgNVBAYTAlVTMRMw
// SIG // EQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRt
// SIG // b25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRp
// SIG // b24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1w
// SIG // IFBDQSAyMDEwAhMzAAAB3MHgjMJfWF6OAAEAAAHcMCIE
// SIG // IAQyU5TPntONrXkg7oKnP7udM/LC3u3NZwLB8M8cgAQv
// SIG // MA0GCSqGSIb3DQEBCwUABIICAIMAFXs2WgVKAmoMeQU1
// SIG // Z2Kdhze2X2haDouHftye4nOuwnt/Kn3rrfoDBR3A7G00
// SIG // w0FzYu/aPI6cwC2P7TY5zcq/hgJnV+xq5k21rE/6IOEI
// SIG // gqjCWZewOn4a6/d0uCy/D9Yxdck3DEu5Z/D2j8q9HU5T
// SIG // mrYcjjc3QMYLA3R/H2u+7o0bQfixYYJEyEB4PGVUvKpX
// SIG // bI6rDVq4K8OUvHhJGMFlO7zYG7ZNbwBCnD/rDOgfNw9r
// SIG // LtrLgcVQ2o0z7eLxcsjsAj6pBiPcI1Y7PkkzFqB5gSKe
// SIG // Xiq8nYOAn6k1H+t6cbiE+qlplK7fgYDqW+lRukKc3XNN
// SIG // 0izup54pmsQp4p8Z5HYlD4E5kkPSeJ+8GqpAUhXNVS4D
// SIG // hG3eSKwDT9Rep+orOXwnLM/MJLQQbrx/FfjO2zi1KJjt
// SIG // wRQXy/TolGvT/DjilzFFbXryjTCJuFUPH4fLV8Z7oeTb
// SIG // 6HZJ1d7i5e9nGn7CWFpU/7gAxUKYTrE0ix9o2fiLPJt8
// SIG // FiPDYEJx11MVWH8Qc0qd0ZF/4yGFtxPebkLJ+YmvnqPb
// SIG // Gb4LEKB9WxJVrzwDXOdqFTFMN3EVBkVHj9zcbS4r1SnY
// SIG // pC3kuxgQAdCrI1FSyRyOeUbmpvFJbGthsIVbC//CFXe3
// SIG // 8jB2KkONi6Q5zaY2Dz11gLVkCwUKENtwx8gI6XbCwK4D
// SIG // yJlV
// SIG // End signature block
